# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.22.1~13699ca',
    built_at='2025-09-04 06:56:15Z',
    sha='13699ca0f74ff51a24bd76e242a89ef434b74658',
    branch='HEAD',
    tag='v4.22.1',
)
